
:mod:`numina.core.recipes` --- Base class for Recipes
=====================================================
.. automodule:: numina.core.recipes
   :synopsis:  Base classes for Recipes
   :members:


:mod:`numina.core.recipeinout` --- Recipe input and output
==========================================================

.. automodule:: numina.core.recipeinout
   :synopsis:  Base classes for Recipe Requirements and Results
   :members:

:mod:`numina.core.dataholders` --- Dataholders
==================================================
.. automodule:: numina.core.dataholders
   :members:


:mod:`numina.core.requirements` --- Recipe requirements
========================================================

.. automodule:: numina.core.requirements
   :members:

:mod:`numina.core.tagexpr` --- Tagger expression
========================================================

.. automodule:: numina.core.tagexpr
   :members: